@@ -225,20 +225,20 @@ SKATBinary_spa<-function (G, obj, weights, method="SKATO",r.corr=NULL){
 
 
 
-#
-# x is either y or SKAT_NULL_Model 
-#
-SKATBinary_Robust.SSD.OneSet = function(SSD.INFO, SetID, obj, ...){
+
+###################################
+# SSD
+
+SKATBinary_Robust.SSD.OneSet = function(SSD.INFO, SetID, obj, ..., obj.SNPWeight=NULL){
   
   id1<-which(SSD.INFO$SetInfo$SetID == SetID)
   if(length(id1) == 0){
     MSG<-sprintf("Error: cannot find set id [%s] from SSD!", SetID)
     stop(MSG)
   }	
-  Set_Index<-SSD.INFO$SetInfo$SetIndex[id1]
+  SetIndex<-SSD.INFO$SetInfo$SetIndex[id1]
   
-  Z<-Get_Genotypes_SSD(SSD.INFO, Set_Index)
-  re<-SKATBinary_Robust(Z, obj, ...)
+  re = SKATBinary_Robust.SSD.OneSet_SetIndex(SSD.INFO, SetIndex, obj, ..., obj.SNPWeight=obj.SNPWeight)
   
   return(re)
 }
@@ -246,19 +246,19 @@ SKATBinary_Robust.SSD.OneSet = function(SSD.INFO, SetID, obj, ...){
 #
 # x is either y or SKAT_NULL_Model 
 #
-SKATBinary_Robust.SSD.OneSet_SetIndex = function(SSD.INFO, SetIndex, obj, ...){
+SKATBinary_Robust.SSD.OneSet_SetIndex = function(SSD.INFO, SetIndex, obj, ..., obj.SNPWeight=NULL){
   
-  id1<-which(SSD.INFO$SetInfo$SetIndex == SetIndex)
-  if(length(id1) == 0){
-    MSG<-sprintf("Error: cannot find set index [%d] from SSD!", SetIndex)
-    stop(MSG)
-  }	
-  SetID<-SSD.INFO$SetInfo$SetID[id1]
+  re1 = SKAT.SSD.GetSNP_Weight(SSD.INFO, SetIndex, obj.SNPWeight=obj.SNPWeight)
+  SetID = SSD.INFO$SetInfo$SetID[SetIndex]
+  if(!re1$Is.weights){
+    re<-SKATBinary_Robust(re1$Z, obj, ...)
+  } else {
+    
+    re<-SKATBinary_Robust(re1$Z, obj, weights=re1$weights, ...)
+  }
   
-  
-  Z<-Get_Genotypes_SSD(SSD.INFO, SetIndex)
-  re<-SKATBinary_Robust(Z, obj, ...)
   return(re)
+  
 }
 
 
@@ -267,7 +267,8 @@ SKATBinary_Robust.SSD.OneSet_SetIndex = function(SSD.INFO, SetIndex, obj, ...){
 #
 # Only SKAT_Null_Model obj can be used
 #
-SKATBinary_Robust.SSD.All = function(SSD.INFO, obj, ...){
+
+SKATBinary_Robust.SSD.All = function(SSD.INFO, obj, ...,obj.SNPWeight=NULL){
   
   N.Set<-SSD.INFO$nSets
   OUT.Pvalue<-rep(NA,N.Set)
@@ -279,6 +280,8 @@ SKATBinary_Robust.SSD.All = function(SSD.INFO, obj, ...){
   
   OUT.nRare<-rep(NA,N.Set)
   OUT.nCommon<-rep(NA,N.Set)
+  OUT.MAC<-rep(NA,N.Set)
+  OUT.snp.mac<-list()
   
   Is.Resampling = FALSE
   n.Resampling = 0
@@ -294,43 +297,26 @@ SKATBinary_Robust.SSD.All = function(SSD.INFO, obj, ...){
   pb <- txtProgressBar(min=0, max=N.Set, style=3)
   for(i in 1:N.Set){
     Is.Error<-TRUE
-    try1<-try(Get_Genotypes_SSD(SSD.INFO, i),silent = TRUE)
-    if(!Is_TryError(try1)){
-      Z<-try1
-      Is.Error<-FALSE
+    try1<-try(SKATBinary_Robust.SSD.OneSet_SetIndex(SSD.INFO, i, obj, ..., obj.SNPWeight=obj.SNPWeight) ,silent = TRUE)
+    if(Is_TryError(try1)){
       
+      err.msg<-geterrmessage()
+      msg<-sprintf("Error to run SKATBinary for %s: %s",SSD.INFO$SetInfo$SetID[i], err.msg)
+      warning(msg,call.=FALSE)
       
     } else {
-      err.msg<-geterrmessage()
-      msg<-sprintf("Error to get genotypes of %s: %s",SSD.INFO$SetInfo$SetID[i], err.msg)
-      warning(msg,call.=FALSE)
-    }
-    
-    if(!Is.Error){
-      Is.Error<-TRUE
-      try2<-try(SKATBinary_Robust(Z, obj, ...),silent = TRUE)
-      
-      if(!Is_TryError(try2)){
-        re<-try2
-        Is.Error<-FALSE
-      } else {
-        
-        err.msg<-geterrmessage()
-        msg<-sprintf("Error to run SKATBinary_Robust for %s: %s",SSD.INFO$SetInfo$SetID[i], err.msg)
-        warning(msg,call.=FALSE)
-      }
-    }
-    
-    if(!Is.Error){
-      
-      OUT.Pvalue[i]<-re$p.value
-      OUT.Marker[i]<-re$param$n.marker
-      OUT.Marker.Test[i]<-re$param$n.marker.test
-      OUT.nRare[i]<-re$n.rare
-      OUT.nCommon[i]<-re$n.common
-      OUT.Q[i]<-re$Q
-      if(Is.Resampling){
-        OUT.Pvalue.Resampling[i,]<-re$p.value.resampling
+      if (max(try1$mac,0,na.rm=T)>=1){
+        re =try1
+        OUT.Pvalue[i]<-re$p.value
+        OUT.Marker[i]<-re$param$n.marker
+        OUT.Marker.Test[i]<-re$param$n.marker.test
+        OUT.MAC[i]<-re$mac
+        OUT.Q[i]<-re$Q
+      #if(Is.Resampling){
+      #  OUT.Pvalue.Resampling[i,]<-re$p.value.resampling
+      #}
+        SetID<-SSD.INFO$SetInfo$SetID[i]
+        OUT.snp.mac[[SetID]]<-re$test.snp.mac
       }
     }
     #if(floor(i/100)*100 == i){
@@ -342,8 +328,8 @@ SKATBinary_Robust.SSD.All = function(SSD.INFO, obj, ...){
   
   close(pb)	
   out.tbl<-data.frame(SetID=SSD.INFO$SetInfo$SetID, P.value=OUT.Pvalue, Q=OUT.Q
-                      , N.Marker.All=OUT.Marker, N.Marker.Test=OUT.Marker.Test, N.Marker.Rare=OUT.nRare, N.Marker.Common=OUT.nCommon)
-  re<-list(results=out.tbl,P.value.Resampling=OUT.Pvalue.Resampling)
+                      , N.Marker.All=OUT.Marker, N.Marker.Test=OUT.Marker.Test, MAC=OUT.MAC)
+  re<-list(results=out.tbl,OUT.snp.mac=OUT.snp.mac)
   class(re)<-"SKAT_SSD_ALL"
   
   return(re)	
@@ -351,6 +337,7 @@ SKATBinary_Robust.SSD.All = function(SSD.INFO, obj, ...){
 
 
 
+
 colMax <- function(data) apply(data,2, max, na.rm = TRUE)
 
 
@@ -482,13 +469,13 @@ SKATBinary_Robust<-function(Z, obj, kernel = "linear.weighted", method="SKAT"
   
   re$param$n.marker<-m.org
   re$param$n.marker.test<-m.test
-  re$param$n.marker.name<-colnames(Z)
   re$param$rho=r.corr
   if (method=="SKATO"){
     re$param$minp=min( re$p.value_each)
     re$param$rho_est=r.corr[which.min(re$p.value_each)]
   }
   re$mac=mac
+  re$test.snp.mac<-SingleSNP_INFO(out$Z.test)
   return(re)
   
 }
