@@ -8,6 +8,8 @@
  * Description:
  *   Deal with *.bed file
  *
+ * Revised by SLEE
+ * Date: May 18, 2017
  **************************************************************/
 #ifndef _BED_READER_H        
 #define _BED_READER_H 
@@ -29,9 +31,18 @@ class BedFileReader
 public:
 	BedFileReader(char* f, char* m, char* fm, char* o, Hasht* ht, int* myerror, char* info = NULL, int MAFConvert=1);
 
+  // Added by SLEE
+  BedFileReader(char* f, char* m, char* fm, int* myerror);
+  void read_One_SNP(int SNPindex, int * genotype, int* myerror);
+  void close_bed();
+    
+  
+  
 	~BedFileReader();
 	size_t m_set_counter; 
 	size_t m_num_of_snps_insetid;
+	
+
 
 private:
 
@@ -58,18 +69,21 @@ private:
 
 	std::ofstream m_info_rewr;
 	size_t m_begin4rw; 
+	
+	// added by SLEE 
 
-	int m_encode_output;
-    int m_MAFConvert; // =1 change coding for minor allele =0 no change
+	//int m_encode_output;
+  int m_MAFConvert; // =1 change coding for minor allele =0 no change
 
 	size_t m_approx_line_lenght;//number of snps
 	SNP_info* m_snp_sets;
 	size_t m_line_counter; // 0 .... NumOfIndividuals
-	size_t m_setnumber;
+	//size_t m_setnumber;
 	size_t m_size_of_esi;
-	size_t m_win_size;
-	size_t m_ovrlp_size;
+	//size_t m_win_size;
+	//size_t m_ovrlp_size;
 
+  // Please add here
 
     void init(const char* bim_file, const char* fam_file, int* myerror);
 	void read_data_and_create_mwo_used_hashtable(Hasht* ht, int* myerror);
